#
# spec file for package python-certbot-apache
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-certbot-apache
Version:        2.9.0
Release:        1.2
Summary:        Apache plugin for Certbot
License:        Apache-2.0
URL:            https://github.com/letsencrypt/letsencrypt
Source:         https://files.pythonhosted.org/packages/source/c/certbot-apache/certbot-apache-%{version}.tar.gz
BuildRequires:  %{python_module augeas}
BuildRequires:  %{python_module certbot >= %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       apache2 >= 2.3
Requires:       python-acme >= %{version}
Requires:       python-augeas
Requires:       python-certbot >= %{version}
BuildArch:      noarch
%python_subpackages

%description
The Apache plugin for Certbot.

%prep
%setup -q -n certbot-apache-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Fri Feb  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.9.0:
  * Support for Python 3.12 was added.
  * Updates `joinpath` syntax to only use one addition per call,
    because the multiple inputs version was causing mypy errors
    on Python 3.10.
  * Makes the `reconfigure` verb actually use the staging server
    for the dry run to check the new configuration.
* Wed Feb  7 2024 Markéta Machová <mmachova@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Dec  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.8.0
  * Added support for Alpine Linux distribution when is used the apache plugin
* Thu Nov 16 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.4
  * sync with the main certbot package
* Tue Oct 31 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.3
  * sync with the main certbot package
* Wed Jun  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.6.0
  * The Apache plugin no longer supports Apache 2.2.
  * Support for Python 3.11 was added to Certbot and all of its components.
  * All Certbot components now require pytest to run tests.
  * Packaged tests for all Certbot components besides josepy were moved inside the _internal/tests module.
  * There is now a new Other annotated challenge object to allow plugins to support entirely novel challenges.
* Thu Oct 27 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.31.0
  * sync with the main certbot package
* Wed Sep 21 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.30.0
  * sync with the main certbot package
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.29.0:
  * --allow-subset-of-names will now additionally retry in cases where domains
    are rejected while creating or finalizing orders. This requires subproblem
    support from the ACME server
  * The show_account subcommand now uses the "newAccount" ACME endpoint to
    fetch the account data, so it doesn't rely on the locally stored account URL.
    This fixes situations where Certbot
    would use old ACMEv1 registration info with non-functional account URLs.
  * The generated Certificate Signing Requests are now generated as version 1
    instead of version 3. This resolves situations in where strict enforcement
    of PKCS#10 meant that CSRs that were generated as version 3 were rejected
* Fri Jun 24 2022 Dirk Müller <dmueller@suse.com>
- update to 1.28.0:
  * Updated Apache/NGINX TLS configs to document contents are based on ssl-config.mozilla.org
  * A change to order finalization has been made to the `acme` module and Certbot:
  - An order's `certificate` field will only be processed if the order's `status` is `valid`.
  - An order's `error` field will only be processed if the order's `status` is `invalid`.
* Mon May 30 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.27.0
  * sync with the main certbot package
* Fri Apr  8 2022 Markéta Machová <mmachova@suse.com>
- Update to version 1.26.0
  * sync with the main certbot package
* Tue Dec 21 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 1.22.0
  * sync with the main certbot package
* Mon Dec 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.19.0
  * Fixed parsing of Defined values in the Apache plugin to allow
    for = in the value.
* Tue Aug 10 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.18.0
  * sync with the main certbot package
* Fri Jul 30 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.17.0
  * Add Void Linux overrides for certbot-apache.
  * The Apache authenticator now always configures virtual hosts which do not have
    an explicit ServerName. This should make it work more reliably with the
    default Apache configuration in Debian-based environments.
* Thu Jun 24 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.16.0
  * Require the latest certbot and acme plugins for simplicity
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.15.0
  * sync with the main certbot package
* Wed Apr 14 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.14.0
  * sync with the main certbot package
* Mon Mar  8 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.13.0
  * Support for Python 2 has been removed.
  * Drop merged patch 0001-Change-the-SUSE-override-to-use-apachectl.patch
* Fri Jan  8 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch to fix the apache2 package not providing apache2ctl
  any longer (gh#certbot/certbot#8592)
  * 0001-Change-the-SUSE-override-to-use-apachectl.patch
* Fri Jan  8 2021 Antonio Larrosa <alarrosa@suse.com>
- update to version 1.11.0
  * We deprecated support for Apache 2.2 in the certbot-apache
    plugin and it will be removed in a future release of Certbot.
- update to version 1.10.1
  * sync with the main certbot package
- update to version 1.10.0
  * Support for Python 3.9 was added to Certbot and all of its
    components.
* Wed Oct  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.9.0
  * The problem causing the Apache plugin in the Certbot snap on ARM systems to
    fail to load the Augeas library it depends on has been fixed.
* Fri Aug 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.7.0
  * Sync with main certbot package.
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.6.0
  * Sync with main certbot package.
* Thu Jun 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.5.0
  * Improved error message in apache installer when mod_ssl is not available.
* Thu May 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.4.0
  * Turn off session tickets for apache plugin by default when appropriate.
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.3.0
  * Sync with main certbot package.
* Fri Feb 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.2.0
  * Disable old SSL versions and ciphersuites and remove SSLCompression off
    setting to follow Mozilla recommendations in Apache.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.0
  * Sync with main certbot package.
* Fri Jan  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.0 (boo#1160066)
  * The docs extras for the certbot-apache and certbot-nginx packages
    have been removed.
* Thu Nov 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.40.1
  * Sync with main certbot package.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Oct  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.39.0
  * Support for Python 3.8 was added to Certbot and all of its components.
* Wed Sep 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.38.0
  * Fixed OS detection in the Apache plugin on Scientific Linux.
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.37.2
  * Turn off session tickets for apache plugin by default
  * Stop disabling TLS session tickets in Apache as it caused TLS
    failures on some systems.
* Wed Jul 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.36.0 (bsc#1141928)
  * The error message when Certbot's Apache plugin is unable to
    modify your Apache configuration has been improved.
* Tue Jun 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.35.1
  * sync with main certbot package
* Sat May 18 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.34.2:
  * lockstep with main certbot package
* Mon Mar 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.32.0
  * Apache plugin now respects CERTBOT_DOCS environment variable
    when adding command line defaults.
  * Tests execution for certbot, certbot-apache and certbot-nginx
    packages now relies on pytest.
* Fri Feb  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.31.0
  * Apache plugin now attempts to configure all VirtualHosts matching
    requested domain name instead of only a single one when answering
    the HTTP-01 challenge.
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.30.2:
  * Various small fixes
* Fri Nov 16 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.28.0
  * Stop preferring TLS-SNI.
  * The grammar used by Augeas parser in Apache plugin was updated
    to fix various parsing errors.
* Fri Sep 14 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.27.1
  * parameter name in OpenSUSE overrides for default parameters
  * several other fixes
* Mon Sep  3 2018 Marketa Calabkova <mcalabkova@suse.com>
- Update runtime requirements
* Wed Aug 29 2018 mcalabkova@suse.com
- Packaged license and readme
* Wed Aug 29 2018 mcalabkova@suse.com
- Split the module from the main certbot package
